@@ -54,9 +54,9 @@
   2010/03/03 - Added [unreachable] prefix used in maintainers.txt.
   2010/05/28 - BOM skipped; minor code cleaning.
   2010/05/31 - e-mail mangled already in maintainers.txt
-  2010/08/20 - maintainers.txt to UTF-8, related processin of unicode strings
+  2010/08/20 - maintainers.txt to UTF-8, related processing of unicode strings
              - [any mark] introduced instead of [unreachable] only
-             - marks hihglighted in HTML
+             - marks highlighted in HTML
   2010/08/30 - Highlighting in what will be the table in langhowto.html modified.
   2010/09/27 - The underscore in \latexonly part of the generated language.doc
                was prefixed by backslash (was LaTeX related error).
@@ -83,15 +83,14 @@ def xopen(fname, mode='r', encoding='utf-8-sig'):
     the default 'utf-8-sig' is used (skips the BOM automatically).
     '''
 
-    major, minor, patch = (int(e) for e in platform.python_version_tuple())
-    if major == 2:
+    if sys.version_info[0] == 2:
         return open(fname, mode=mode) # Python 2 without encoding
     else:
         return open(fname, mode=mode, encoding=encoding) # Python 3 with encoding
 
 
 def fill(s):
-    """Returns string formated to the wrapped paragraph multiline string.
+    """Returns string formatted to the wrapped paragraph multiline string.
 
     Replaces whitespaces by one space and then uses he textwrap.fill()."""
 
@@ -142,8 +141,8 @@ class Transl:
         self.baseClassId = None
         self.readableStatus = None   # 'up-to-date', '1.2.3', '1.3', etc.
         self.status = None           # '', '1.2.03', '1.3.00', etc.
-        self.lang = None             # like 'Brasilian'
-        self.langReadable = None     # like 'Brasilian Portuguese'
+        self.lang = None             # like 'Brazilian'
+        self.langReadable = None     # like 'Brazilian Portuguese'
         self.note = None             # like 'should be cleaned up'
         self.prototypeDic = {}       # uniPrototype -> prototype
         self.translateMeText = 'translate me!'
@@ -159,7 +158,7 @@ class Transl:
 
         The tokens have the form (tokenId, tokenString, lineNo). The
         last returned token has the form ('eof', None, None). When trying
-        to access next token afer that, the exception would be raised."""
+        to access next token after that, the exception would be raised."""
 
         # Set the dictionary for recognizing tokenId for keywords, separators
         # and the similar categories. The key is the string to be recognized,
@@ -625,8 +624,8 @@ class Transl:
                 else:
                     self.__unexpectedToken(status, tokenId, tokenLineNo)
 
-            elif status == 8:    # zero expected
-                if tokenId == 'num' and tokenStr == '0':
+            elif status == 8:    # zero expected (or default for the destructor)
+                if (tokenId == 'num' and tokenStr == '0') or (tokenId == 'id' and tokenStr == 'default'):
                     status = 9
                 else:
                     self.__unexpectedToken(status, tokenId, tokenLineNo)
@@ -727,7 +726,7 @@ class Transl:
         The dictionary is filled by items: uniPrototype -> prototype.
         The method is expected to be called only for TranslatorXxxx classes,
         i.e. for the classes that implement translation to some language.
-        It assumes that the openning curly brace of the class was already
+        It assumes that the opening curly brace of the class was already
         consumed. The source is consumed until the end of the class.
         The caller should consume the source until the eof to cause closing
         the source file."""
@@ -738,7 +737,7 @@ class Transl:
         # The following finite automaton slightly differs from the one
         # inside self.collectPureVirtualPrototypes(). It produces the
         # dictionary item just after consuming the body of the method
-        # (transition from from state 10 to state 2). It also does not allow
+        # (transition from state 10 to state 2). It also does not allow
         # definitions of public pure virtual methods, except for
         # TranslatorAdapterBase (states 8 and 9). Argument identifier inside
         # method argument lists can be omitted or commented.
@@ -876,8 +875,14 @@ class Transl:
                             assert False
 
                         assert(uniPrototype not in self.prototypeDic)
-                        # Insert new dictionary item.
-                        self.prototypeDic[uniPrototype] = prototype
+                        # Insert new dictionary item, unless they have a default in translator.h
+                        if (not (prototype=="virtual QCString latexDocumentPost()" or
+                                 prototype=="virtual QCString latexDocumentPre()" or
+                                 prototype=="virtual QCString latexCommandName()" or
+                                 prototype=="virtual QCString latexFont()" or
+                                 prototype=="virtual QCString latexFontenc()" or
+                                 prototype=="virtual bool needsPunctuation()")):
+                            self.prototypeDic[uniPrototype] = prototype
                         status = 2      # body consumed
                         methodId = None # outside of any method
                 elif tokenId == 'lcurly':
@@ -1123,13 +1128,13 @@ class Transl:
         # be set.
         if not self.note and self.status == '' and \
            (self.translateMeFlag or self.txtMAX_DOT_GRAPH_HEIGHT_flag):
-           self.note = ''
-           if self.translateMeFlag:
-               self.note += 'The "%s" found in a comment.' % self.translateMeText
-           if self.note != '':
-               self.note += '\n\t\t'
-           if self.txtMAX_DOT_GRAPH_HEIGHT_flag:
-               self.note += 'The MAX_DOT_GRAPH_HEIGHT found in trLegendDocs()'
+            self.note = ''
+            if self.translateMeFlag:
+                self.note += 'The "%s" found in a comment.' % self.translateMeText
+            if self.note != '':
+                self.note += '\n\t\t'
+            if self.txtMAX_DOT_GRAPH_HEIGHT_flag:
+                self.note += 'The MAX_DOT_GRAPH_HEIGHT found in trLegendDocs()'
 
         # If everything seems OK, but there are obsolete methods, set
         # the note to clean-up source. This note will be used only when
@@ -1227,14 +1232,26 @@ class TrManager:
         doxy_default = os.path.join(self.script_path, '..')
         self.doxy_path = os.path.abspath(os.getenv('DOXYGEN', doxy_default))
 
-        # Get the explicit arguments of the script.
-        self.script_argLst = sys.argv[1:]
-
         # Build the path names based on the Doxygen's root knowledge.
         self.doc_path = os.path.join(self.doxy_path, 'doc')
         self.src_path = os.path.join(self.doxy_path, 'src')
+        #  Normally the original sources aren't in the current directory
+        # (as we are in the build directory) so we have to specify the
+        # original source /documentation / ... directory.
+        self.org_src_path = self.src_path
+        self.org_doc_path = self.doc_path
+        self.org_doxy_path = self.doxy_path
+        if (len(sys.argv) > 1 and os.path.isdir(os.path.join(sys.argv[1], 'src'))):
+            self.org_src_path = os.path.join(sys.argv[1], 'src')
+            self.org_doc_path = os.path.join(sys.argv[1], 'doc')
+            self.org_doxy_path = sys.argv[1]
+            # Get the explicit arguments of the script.
+            self.script_argLst = sys.argv[2:]
+        else:
+            # Get the explicit arguments of the script.
+            self.script_argLst = sys.argv[1:]
 
-        # Create the empty dictionary for Transl object identitied by the
+        # Create the empty dictionary for Transl object identified by the
         # class identifier of the translator.
         self.__translDic = {}
 
@@ -1283,7 +1300,7 @@ class TrManager:
         # The translator.h must exist (the Transl object will check it),
         # create the object for it and let it build the dictionary of
         # required methods.
-        tr = Transl(os.path.join(self.src_path, 'translator.h'), self)
+        tr = Transl(os.path.join(self.org_src_path, 'translator.h'), self)
         self.requiredMethodsDic = tr.collectPureVirtualPrototypes()
         tim = tr.getmtime()
         if tim > self.lastModificationTime:
@@ -1291,7 +1308,7 @@ class TrManager:
 
         # The translator_adapter.h must exist (the Transl object will check it),
         # create the object for it and store the reference in the dictionary.
-        tr = Transl(os.path.join(self.src_path, 'translator_adapter.h'), self)
+        tr = Transl(os.path.join(self.org_src_path, 'translator_adapter.h'), self)
         self.adaptMethodsDic = tr.collectAdapterPrototypes()
         tim = tr.getmtime()
         if tim > self.lastModificationTime:
@@ -1303,11 +1320,11 @@ class TrManager:
         if self.script_argLst:
             lst = ['translator_' + x + '.h' for x in self.script_argLst]
             for fname in lst:
-                if not os.path.isfile(os.path.join(self.src_path, fname)):
+                if not os.path.isfile(os.path.join(self.org_src_path, fname)):
                     sys.stderr.write("\a\nFile '%s' not found!\n" % fname)
                     sys.exit(1)
         else:
-            lst = os.listdir(self.src_path)
+            lst = os.listdir(self.org_src_path)
             lst = [x for x in lst if x[:11] == 'translator_'
                                    and x[-2:] == '.h'
                                    and x != 'translator_adapter.h']
@@ -1316,7 +1333,7 @@ class TrManager:
         # content of the file. Then insert the object to the dictionary
         # accessed via classId.
         for fname in lst:
-            fullname = os.path.join(self.src_path, fname)
+            fullname = os.path.join(self.org_src_path, fname)
             tr = Transl(fullname, self)
             tr.processing()
             assert(tr.classId != 'Translator')
@@ -1395,7 +1412,7 @@ class TrManager:
                     self.numLang -= 1    # the couple will be counted as one
 
         # Extract the version of Doxygen.
-        f = xopen(os.path.join(self.doxy_path, 'VERSION'))
+        f = xopen(os.path.join(self.org_doxy_path, 'VERSION'))
         self.doxVersion = f.readline().strip()
         f.close()
 
@@ -1414,15 +1431,15 @@ class TrManager:
         are searched in doxygen/src directory.
         """
         files = []
-        for item in os.listdir(self.src_path):
+        for item in os.listdir(self.org_src_path):
             # Split the bare name to get the extension.
             name, ext = os.path.splitext(item)
             ext = ext.lower()
 
             # Include only .cpp and .h files (case independent) and exclude
             # the files where the checked identifiers are defined.
-            if ext == '.cpp' or (ext == '.h' and name.find('translator') == -1):
-                fname = os.path.join(self.src_path, item)
+            if ext == '.cpp' or ext ==  '.l' or (ext == '.h' and name.find('translator') == -1):
+                fname = os.path.join(self.org_src_path, item)
                 assert os.path.isfile(fname) # assumes no directory with the ext
                 files.append(fname)          # full name
         return files
@@ -1445,12 +1462,14 @@ class TrManager:
         assert os.path.isfile(fname)
         f = xopen(fname)
         cont = f.read()
+        cont = ''.join(cont.split('\n')) # otherwise the 'match' function won't work.
         f.close()
 
         # Remove the items for identifiers that were found in the file.
         while lst_in:
             item = lst_in.pop(0)
-            if cont.find(item) != -1:
+            rexItem = re.compile('.*' + item + ' *\(')
+            if rexItem.match(cont):
                 del dic[item]
 
 
@@ -1484,7 +1503,7 @@ class TrManager:
     def __emails(self, classId):
         """Returns the list of maintainer emails.
 
-        The method returns the list of e-mail adresses for the translator
+        The method returns the list of e-mail addresses for the translator
         class, but only the addresses that were not marked as [xxx]."""
         lst = []
         for m in self.__maintainersDic[classId]:
@@ -1548,7 +1567,7 @@ class TrManager:
         # The e-mail addresses of the maintainers will be collected to
         # the auxiliary file in the order of translator classes listed
         # in the translator report.
-        fmail = xopen('mailto.txt', 'w')
+        fmail = xopen(os.path.join(self.doc_path, 'mailto.txt'), 'w')
 
         # Write the list of "up-to-date" translator classes.
         if self.upToDateIdLst:
@@ -1711,7 +1730,7 @@ class TrManager:
 
         Fills the dictionary classId -> [(name, e-mail), ...]."""
 
-        fname = os.path.join(self.doc_path, self.maintainersFileName)
+        fname = os.path.join(self.org_doc_path, self.maintainersFileName)
 
         # Include the maintainers file to the group of files checked with
         # respect to the modification time.
@@ -1763,10 +1782,16 @@ class TrManager:
         """Checks the modtime of files and generates language.doc."""
         self.__loadMaintainers()
 
+        # Check the last modification time of the VERSION file.
+        fVerName = os.path.join(self.org_doxy_path, "VERSION")
+        tim = os.path.getmtime(fVerName)
+        if tim > self.lastModificationTime:
+            self.lastModificationTime = tim
+
         # Check the last modification time of the template file. It is the
         # last file from the group that decide whether the documentation
         # should or should not be generated.
-        fTplName = os.path.join(self.doc_path, self.languageTplFileName)
+        fTplName = os.path.join(self.org_doc_path, self.languageTplFileName)
         tim = os.path.getmtime(fTplName)
         if tim > self.lastModificationTime:
             self.lastModificationTime = tim
@@ -1805,15 +1830,15 @@ class TrManager:
         tplDic['supportedLangReadableStr'] = self.supportedLangReadableStr
         tplDic['translatorReportFileName'] = self.translatorReportFileName
 
-        ahref = '<a href="../doc/' + self.translatorReportFileName
-        ahref += '"\n><code>doxygen/doc/'  + self.translatorReportFileName
-        ahref += '</code></a>'
+        ahref = '<a href="' + self.translatorReportFileName
+        ahref += '"\n><code>'  + self.translatorReportFileName + '</code></a>'
         tplDic['translatorReportLink'] = ahref
         tplDic['numLangStr'] = str(self.numLang)
 
         # Define templates for HTML table parts of the documentation.
-        htmlTableTpl = '''\
+        htmlTableTpl = '''
             \\htmlonly
+            </p>
             <table align="center" cellspacing="0" cellpadding="0" border="0">
             <tr bgcolor="#000000">
             <td>
@@ -1832,6 +1857,7 @@ class TrManager:
             </td>
             </tr>
             </table>
+            <p>
             \\endhtmlonly
             '''
         htmlTableTpl = textwrap.dedent(htmlTableTpl)
@@ -1845,7 +1871,7 @@ class TrManager:
         for name, obj in self.langLst:
             # Fill the table data elements for one row. The first element
             # contains the readable name of the language. Only the oldest
-            # translator are colour marked in the language columnt. Less
+            # translator are colour marked in the language column. Less
             # "heavy" color is used (when compared with the Status column).
             if obj.readableStatus.startswith('1.4'):
                 bkcolor = self.getBgcolorByReadableStatus('1.4')
@@ -1866,7 +1892,7 @@ class TrManager:
                 if classId in self.__translDic:
                     lang = self.__translDic[classId].langReadable
                     mm = 'see the %s language' % lang
-                    ee = '&nbsp;'
+                    ee = '&#160;'
 
             if not mm and obj.classId in self.__maintainersDic:
                 # Build a string of names separated by the HTML break element.
@@ -1880,7 +1906,7 @@ class TrManager:
                     lm.append(name)
                 mm = '<br/>'.join(lm)
 
-                # The marked adresses (they start with the mark '[unreachable]',
+                # The marked addresses (they start with the mark '[unreachable]',
                 # '[resigned]', whatever '[xxx]') will not be displayed at all.
                 # Only the mark will be used instead.
                 rexMark = re.compile('(?P<mark>\\[.*?\\])')
@@ -1987,10 +2013,11 @@ class TrManager:
 
 if __name__ == '__main__':
 
-    # The Python 2.6+ or 3.3+ is required.
-    major, minor, patch = (int(e) for e in platform.python_version_tuple())
-    if (major == 2 and minor < 6) or (major == 3 and minor < 0):
-        print('Python 2.6+ or Python 3.0+ are required for the script')
+    # The Python 2.7+ or 3.3+ is required.
+    major = sys.version_info[0]
+    minor = sys.version_info[1]
+    if (major == 2 and minor < 7) or (major == 3 and minor < 0):
+        print('Python 2.7+ or Python 3.0+ are required for the script')
         sys.exit(1)
 
     # The translator manager builds the Transl objects, parses the related
