@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -35,7 +35,7 @@
  files frees the maintainer from thinking about whether the
  first, the second, or both files should be included or not, and
  why.  This holds namely for localized translators because their
- base class is changed occasionaly to adapter classes when the
+ base class is changed occasionally to adapter classes when the
  Translator class changes the interface, or back to the
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
@@ -75,6 +75,15 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
       return "\\usepackage[catalan]{babel}\n";
     }
 
+    virtual QCString trISOLang()
+    {
+      return "ca";
+    }
+    virtual QCString getLanguageString()
+    {
+      return "0x403 Catalan";
+    }
+
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -104,7 +113,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Documentació dels Camps";
       }
@@ -137,9 +146,9 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Generat automàticament per Doxygen";
-      if (s) result+=(QCString)" per a "+s;
+      if (!s.isEmpty()) result+=" per a "+s;
       result+=" a partir del codi font.";
       return result;
     }
@@ -171,7 +180,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Estructures de Dades";
       }
@@ -188,7 +197,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Camps de Dades";
       }
@@ -201,7 +210,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Globals";
       }
@@ -242,10 +251,14 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Aquestes són les estructures de dades acompanyades amb breus descripcions:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Aquestes són les classes acompanyades amb breus descripcions:";
+      }
       else
       {
         return "Aquestes són les classes, estructures, "
@@ -257,7 +270,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     virtual QCString trCompoundMembersDescription(bool extractAll)
     {
       QCString result="Aquesta és la llista de tots els ";
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="camps d'estructures i unions";
       }
@@ -272,7 +285,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
       result+=" amb enllaços a ";
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="la documentació de l'estructura/unió per a cada camp:";
         }
@@ -283,7 +296,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="les estructures/unions a que pertanyen:";
         }
@@ -298,7 +311,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     virtual QCString trFileMembersDescription(bool extractAll)
     {
       QCString result="Aquesta és la llista de ";
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="totes les funcions, variables, definicions, enumeracions, i definicions de tipus";
         if (!extractAll) result+=" documentades";
@@ -352,7 +365,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Índex d'Estructures de Dades";
       }
@@ -379,10 +392,14 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Documentació de les Estructures de Dades";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Documentació de les Classes";
@@ -401,12 +418,6 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     virtual QCString trExampleDocumentation()
     { return "Documentació dels Exemples"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Documentació de les Pàgines"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Manual de Referència"; }
@@ -482,7 +493,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Estructures de Dades";
       }
@@ -495,24 +506,20 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Generat a "+date;
-      if (projName) result+=(QCString)" per a "+projName;
-      result+=(QCString)" per";
+      QCString result="Generat a "+date;
+      if (!projName.isEmpty()) result+=" per a "+projName;
+      result+=" per";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama d'Herència per a "+clName+":";
+      return "Diagrama d'Herència per a "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Tan sols per a ús intern."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Atenció"; }
@@ -583,7 +590,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -600,12 +607,12 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
         default: break;
       }
       if (isTemplate) result+="Template ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result="Referència del Fitxer ";
       result+=fileName;
@@ -613,7 +620,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Referència de l'Espai de Noms ";
       result+=namespaceName;
@@ -747,7 +754,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentació d'aquest";
+      QCString result="La documentació d'aquest";
       switch(compType)
       {
         case ClassDef::Class:      result+="a classe"; break;
@@ -814,14 +821,14 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de col·laboració per a "+clName+":";
+      return "Diagrama de col·laboració per a "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Inclou el graf de dependències per a "+fName+":";
+      return "Inclou el graf de dependències per a "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -894,7 +901,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Camps de Dades";
       }
@@ -1019,7 +1026,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
         "};\n"
         "\\endcode\n"
         "Resultarà el gràfic següent:"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "Les caixes del gràfic superior tenen aquesta interpretació:\n"
         "<ul>\n"
@@ -1083,7 +1090,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Estructures de Dades";
       }
@@ -1093,14 +1100,9 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paquet "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Llista de Paquets";
+      return "Paquet "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1357,14 +1359,18 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funcions de Paquet";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Membres de Paquet";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Funcions Estàtiques de Paquet";
     }
@@ -1476,18 +1482,10 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "Directoris"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Aquesta jerarquia de directoris està ordenada toscament, "
-             "però no completa, de forma alfabètica:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result="Referència del Directori "; result+=dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1614,7 +1612,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1631,12 +1629,12 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
         default: break;
       }
       if (isTemplate) result+="Template ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Referència del Mòdul ";
       result+=namespaceName;
@@ -1690,7 +1688,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentació d'aquest";
+      QCString result="La documentació d'aquest";
       switch(compType)
       {
         case ClassDef::Class:      result+=" mòdul"; break;
@@ -1744,7 +1742,7 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" Relació";
     }
@@ -1781,18 +1779,18 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Fitxer a "+name;
+      return "Fitxer a "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Inclou fitxer a "+name;
+      return "Inclou fitxer a "+name;
     }
 
     /** Compiles a date string.
@@ -1821,6 +1819,27 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "dl.", "dt.", "dc.", "dj.", "dv.", "ds.", "dg." };
+      static const char *days_full[]    = { "dilluns", "dimarts", "dimecres", "dijous", "divendres", "dissabte", "diumenge" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "gen.", "febr.", "març", "abr.", "maig", "juny", "jul.", "ag.", "set.", "oct.", "nov.", "des." };
+      static const char *months_full[]  = { "gener", "febrer", "març", "abril", "maig", "juny", "juliol", "agost", "setembre", "octubre", "novembre", "desembre" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "a.m.", "p.m." };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1835,9 +1854,10 @@ class TranslatorCatalan : public TranslatorAdapter_1_8_0
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Graf de dependència de directoris per a ")+name+":"; }
 
+
 };
 
 #endif
