@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -43,17 +43,13 @@
  files frees the maintainer from thinking about whether the
  first, the second, or both files should be included or not, and
  why.  This holds namely for localized translators because their
- base class is changed occasionaly to adapter classes when the
+ base class is changed occasionally to adapter classes when the
  Translator class changes the interface, or back to the
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
 */
-class TranslatorKorean : public Translator
+class TranslatorKorean : public TranslatorAdapter_1_8_15
 {
-  protected:
-    friend class TranslatorAdapterBase;
-    virtual ~TranslatorKorean() {}
-
   public:
 
     // --- Language control methods -------------------
@@ -86,9 +82,30 @@ class TranslatorKorean : public Translator
       // I'm not sure what this should be.
       // When I figure it out, I'll update this.
       // see http://www.ktug.or.kr/jsboard/read.php?table=operate&no=4422&page=1
-      return "\\usepackage{hfont}\n";
+      return "\\usepackage{kotex}\n";
+    }
+    virtual QCString latexCommandName()
+    {
+      QCString latex_command = Config_getString(LATEX_CMD_NAME);
+      if (latex_command.isEmpty()) latex_command = "latex";
+      if (Config_getBool(USE_PDFLATEX))
+      {
+        if (latex_command == "latex") latex_command = "xelatex";
+      }
+      return latex_command;
+    }
+    virtual QCString trISOLang()
+    {
+      return "ko";
+    }
+    virtual QCString getLanguageString()
+    {
+      return "0x412 Korean";
+    }
+    virtual bool needsPunctuation()
+    {
+      return false;
     }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -118,13 +135,13 @@ class TranslatorKorean : public Translator
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
           return "필드 문서화";
       }
       else
       {
-          return "멤버 데이타 문서화";
+          return "멤버 데이터 문서화";
       }
     }
 
@@ -151,9 +168,9 @@ class TranslatorKorean : public Translator
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="소스 코드로부터 ";
-      if (s) result+=s+(QCString)"를 위해 ";
+      if (!s.isEmpty()) result+=s+"를 위해 ";
       result+="Doxygen에 의해 자동으로 생성됨.";
       return result;
     }
@@ -185,9 +202,9 @@ class TranslatorKorean : public Translator
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 구조";
+        return "데이터 구조";
       }
       else
       {
@@ -202,9 +219,9 @@ class TranslatorKorean : public Translator
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 필드";
+        return "데이터 필드";
       }
       else
       {
@@ -215,7 +232,7 @@ class TranslatorKorean : public Translator
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "전역";
       }
@@ -255,9 +272,9 @@ class TranslatorKorean : public Translator
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "다음은 데이타 구조들입니다. (간략한 설명만을 보여줍니다) :";
+        return "다음은 데이터 구조들입니다. (간략한 설명만을 보여줍니다) :";
       }
       else
       {
@@ -274,7 +291,7 @@ class TranslatorKorean : public Translator
       {
         result+="문서화된 ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="모든 구조체와 공용체의 필드들";
       }
@@ -286,7 +303,7 @@ class TranslatorKorean : public Translator
 
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="각 필드들은 해당 필드에 대한 구조체와 공용체의 "
 		  "문서화 페이지의 링크를 가지고 있습니다. :";
@@ -299,7 +316,7 @@ class TranslatorKorean : public Translator
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="각 필드들은 해당 필드가 속해 있는 구조체와 공용체에 "
 		  "대한 링크를 가지고 있습니다. :";
@@ -319,7 +336,7 @@ class TranslatorKorean : public Translator
       QCString result="다음은 ";
       if (!extractAll) result+="문서화된  ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="모든 함수, 변수, 매크로, 열거형, 타입정의들";
       }
@@ -372,9 +389,9 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 구조 색인";
+        return "데이터 구조 색인";
       }
       else
       {
@@ -399,9 +416,13 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 구조 문서화";
+        return "데이터 구조 문서화";
+      }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
       }
       else
       {
@@ -421,12 +442,6 @@ class TranslatorKorean : public Translator
     virtual QCString trExampleDocumentation()
     { return "예제 문서화"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "페이지 문서화"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "참조 매뉴얼"; }
@@ -502,9 +517,9 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 구조";
+        return "데이터 구조";
       }
       else
       {
@@ -515,24 +530,20 @@ class TranslatorKorean : public Translator
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"생성시간 : "+date;
-      if (projName) result+=(QCString)", 프로젝트명 : "+projName;
-      result+=(QCString)", 생성자 : ";
+      QCString result="생성시간 : "+date;
+      if (!projName.isEmpty()) result+=", 프로젝트명 : "+projName;
+      result+=", 생성자 : ";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)clName+"에 대한 상속 다이어그램 : ";
+      return clName+"에 대한 상속 다이어그램 : ";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "내부적적으로만 사용하기 위해."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "경고"; }
@@ -603,11 +614,11 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" 클래스"; break;
@@ -625,7 +636,7 @@ class TranslatorKorean : public Translator
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result=fileName;
       result+=" 파일 참조";
@@ -633,7 +644,7 @@ class TranslatorKorean : public Translator
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" 네임스페이스 참조";
@@ -767,7 +778,7 @@ class TranslatorKorean : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"이 ";
+      QCString result="이 ";
       switch(compType)
       {
         case ClassDef::Class:      result+="클래스"; break;
@@ -831,14 +842,14 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)clName+"에 대한 협력 다이어그램:";
+      return clName+"에 대한 협력 다이어그램:";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)fName+"에 대한 include 의존 그래프";
+      return fName+"에 대한 include 의존 그래프";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -911,9 +922,9 @@ class TranslatorKorean : public Translator
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 필드";
+        return "데이터 필드";
       }
       else
       {
@@ -1035,7 +1046,7 @@ class TranslatorKorean : public Translator
         "};\n"
         "\\endcode\n"
         "다음과 같은 그래프가 출력될 것입니다. :"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "위 그래프의 박스들은 다음과 같은 의미를 가집니다. :\n"
         "<ul>\n"
@@ -1100,9 +1111,9 @@ class TranslatorKorean : public Translator
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-        return "데이타 구조";
+        return "데이터 구조";
       }
       else
       {
@@ -1110,14 +1121,9 @@ class TranslatorKorean : public Translator
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return name+(QCString)" 패키지";
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "패키지 목록";
+      return name+" 패키지";
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1374,14 +1380,18 @@ class TranslatorKorean : public Translator
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "패키지 함수";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "패키지 멤버들";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "정적 패키지 함수";
     }
@@ -1493,17 +1503,10 @@ class TranslatorKorean : public Translator
     virtual QCString trDirectories()
     { return "디렉토리"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "이 디렉토리 목록은 완전하진 않지만, (대략적으로) 알파벳순으로 정렬되어있습니다.:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+=" 디렉토리 참조"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1555,15 +1558,15 @@ class TranslatorKorean : public Translator
 
     /*! This is put above each page as a link to the list of annotated data types (Fortran). */
     virtual QCString trCompoundListFortran()
-    { return "데이타 타입 목록"; }
+    { return "데이터 타입 목록"; }
 
     /*! This is put above each page as a link to all members of compounds (Fortran). */
     virtual QCString trCompoundMembersFortran()
-    { return "데이타 필드"; }
+    { return "데이터 필드"; }
 
     /*! This is an introduction to the annotated compound list (Fortran). */
     virtual QCString trCompoundListDescriptionFortran()
-    { return "대략적인 설명과 함께 데이타 타입들의 목록입니다.:"; }
+    { return "대략적인 설명과 함께 데이터 타입들의 목록입니다.:"; }
 
     /*! This is an introduction to the page with all data types (Fortran). */
     virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
@@ -1573,16 +1576,16 @@ class TranslatorKorean : public Translator
       {
         result+="문서화된 ";
       }
-      result+="모든 데이타 타입 멤버들의 목록입니다. ";
+      result+="모든 데이터 타입 멤버들의 목록입니다. ";
 
       result+="각 항목은 ";
       if (!extractAll)
       {
-         result+="각 멤버에 대한 데이타 구조 문서화 페이지의 링크를 가지고 있습니다.";
+         result+="각 멤버에 대한 데이터 구조 문서화 페이지의 링크를 가지고 있습니다.";
       }
       else
       {
-         result+="그들이 속한 데이타 타입의 링크를 가지고 있습니다. :";
+         result+="그들이 속한 데이터 타입의 링크를 가지고 있습니다. :";
       }
       return result;
     }
@@ -1591,13 +1594,13 @@ class TranslatorKorean : public Translator
      * annotated compound index (Fortran).
      */
     virtual QCString trCompoundIndexFortran()
-    { return "데이타 타입 색인"; }
+    { return "데이터 타입 색인"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all data types (Fortran).
      */
     virtual QCString trTypeDocumentation()
-    { return "데이타 타입 문서화"; }
+    { return "데이터 타입 문서화"; }
 
     /*! This is used in the documentation of a file as a header before the
      *  list of (global) subprograms (Fortran).
@@ -1615,7 +1618,7 @@ class TranslatorKorean : public Translator
      *  the list of links to documented compounds (Fortran)
      */
      virtual QCString trDataTypes()
-    { return "데이타 타입들"; }
+    { return "데이터 타입들"; }
 
     /*! used as the title of page containing all the index of all modules (Fortran). */
     virtual QCString trModulesList()
@@ -1631,11 +1634,11 @@ class TranslatorKorean : public Translator
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" 모듈"; break;
@@ -1652,7 +1655,7 @@ class TranslatorKorean : public Translator
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" 모듈 참조";
@@ -1703,7 +1706,7 @@ class TranslatorKorean : public Translator
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"다음 파일";
+      QCString result="다음 파일";
       if (single) result+=""; else result+="들";
       result+="로부터 생성된 ";
       result+="이 ";
@@ -1753,7 +1756,7 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" 관계";
     }
@@ -1790,7 +1793,7 @@ class TranslatorKorean : public Translator
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
       return QCString(name) + "의 파일";
     }
@@ -1799,7 +1802,7 @@ class TranslatorKorean : public Translator
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
       return QCString(name) + "의 파일 포함";
     }
@@ -1830,6 +1833,25 @@ class TranslatorKorean : public Translator
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "월", "화", "수", "목", "금", "토", "일" };
+      static const char *days_full[]    = { "월요일", "화요일", "수요일", "목요일", "금요일", "토요일", "일요일" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12" };
+      static const char *months_full[]  = { "1월", "2월", "3월", "4월", "5월", "6월", "7월", "8월", "9월", "10월", "11월", "12월" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "오전", "오후" };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1844,7 +1866,7 @@ class TranslatorKorean : public Translator
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString(name) + QCString("에 대한 디렉토리 의존성 그래프:"); }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1870,11 +1892,11 @@ class TranslatorKorean : public Translator
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" Enum Reference"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(what) + QCString("(으)로부터 상속된 ") + QCString(members); }
 
     /*! Header of the sections with inherited members specific for the
@@ -1903,7 +1925,7 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trProvidedByCategory()
     {
-      return "카테고리 @1에 의해 제공됨.";
+      return "카테고리 @0에 의해 제공됨.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1912,7 +1934,7 @@ class TranslatorKorean : public Translator
      */
     virtual QCString trExtendsClass()
     {
-      return "클래스 @1 확장.";
+      return "클래스 @0 확장.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
@@ -1938,14 +1960,6 @@ class TranslatorKorean : public Translator
       return "메소드 문서화";
     }
 
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "디자인 개요";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.8.4
 //////////////////////////////////////////////////////////////////////////
@@ -1963,23 +1977,23 @@ class TranslatorKorean : public Translator
     { return "상수 그룹들"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" 상수 그룹 레퍼런스";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" 서비스 레퍼런스";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" 싱글톤 레퍼런스";
       return result;
     }
@@ -1987,7 +2001,7 @@ class TranslatorKorean : public Translator
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"이 서비스에 대한 문서화는 다음의 파일";
+      QCString result="이 서비스에 대한 문서화는 다음의 파일";
       if (!single) result+="들";
 	  result+="로부터 생성되었습니다.:";
       return result;
@@ -1996,14 +2010,12 @@ class TranslatorKorean : public Translator
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"이 싱글톤에 대한 문서화는 다음의 파일";
+      QCString result="이 싱글톤에 대한 문서화는 다음의 파일";
       if (!single) result+="들";
 	  result+="로부터 생성되었습니다.:";
       return result;
     }
 
-//////////////////////////////////////////////////////////////////////////
-
 };
 
 #endif
