@@ -35,7 +35,7 @@
  files frees the maintainer from thinking about whether the
  first, the second, or both files should be included or not, and
  why.  This holds namely for localized translators because their
- base class is changed occasionaly to adapter classes when the
+ base class is changed occasionally to adapter classes when the
  Translator class changes the interface, or back to the
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
@@ -76,10 +76,19 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage[LV]{fontenc}\n"
+      return "\\usepackage[T2A]{fontenc}\n"
              "\\usepackage[latvian]{babel}\n";
     }
 
+    virtual QCString trISOLang()
+    {
+      return "lv";
+    }
+    virtual QCString getLanguageString()
+    {
+      return "0x426 Latvian";
+    }
+
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -109,7 +118,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Lauka dokumentācija";
       }
@@ -142,9 +151,9 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automātiski ģenerēts izmantojot Doxygen";
-      if (s) result+=(QCString)" priekš "+s;
+      if (!s.isEmpty()) result+=" priekš "+s;
       result+=" no pirmkoda.";
       return result;
     }
@@ -176,7 +185,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu struktūras";
       }
@@ -193,7 +202,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu lauki";
       }
@@ -206,7 +215,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Globālie";
       }
@@ -247,10 +256,14 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Šeit ir visas datu struktūras ar īsu aprakstu:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Šeit ir visas klases ar īsu aprakstu:";
+      }
       else
       {
         return "Šeit ir visas klases, struktūras, "
@@ -266,7 +279,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       {
         result+="dokumentēto ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="struktūru un apvienojumu lauku";
       }
@@ -277,7 +290,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       result+=" saraksts ar saitēm uz ";
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="struktūru/apvienojumu dokumentāciju katram laukam:";
         }
@@ -288,7 +301,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="struktūrām/apvienojumiem, kam tie pieder:";
         }
@@ -306,7 +319,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       QCString result="Šeit ir visu ";
       if (!extractAll) result+="dokumentēto ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="funkciju, mainīgo, definīciju, uzskaitījumliterāļu un typedefs";
       }
@@ -357,7 +370,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu struktūru indess";
       }
@@ -384,10 +397,14 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu struktūras dokomentācija";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klases dokumentācija";
@@ -406,12 +423,6 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trExampleDocumentation()
     { return "Piemēri"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Lapas dokumentācija"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Rokasgrāmata"; }
@@ -487,7 +498,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu struktūras";
       }
@@ -500,24 +511,20 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Ģenerēts "+date;
-      if (projName) result+=(QCString)" projektam "+projName;
-      result+=(QCString)" ar";
+      QCString result="Ģenerēts "+date;
+      if (!projName.isEmpty()) result+=" projektam "+projName;
+      result+=" ar";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Mantojamības diagramma klasei "+clName+":";
+      return "Mantojamības diagramma klasei "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Tikai iekšējai lietošanai."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Brīdinājums"; }
@@ -588,11 +595,11 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" klases"; break;
@@ -610,7 +617,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result=fileName;
       result+=" faila apraksts";
@@ -618,7 +625,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" nosaukumvietas apraksts";
@@ -751,7 +758,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     { // single is true implies a single file
-      QCString result=(QCString)"Šī";
+      QCString result="Šī";
       switch(compType)
       {
         case ClassDef::Class:      result+="s klases"; break;
@@ -814,14 +821,14 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Sadarbības diagramma klasei "+clName+":";
+      return "Sadarbības diagramma klasei "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Include dependency graph for "+fName+":";
+      return "Include dependency graph for "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -894,7 +901,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu lauki";
       }
@@ -1092,7 +1099,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datu struktūras";
       }
@@ -1102,14 +1109,9 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pakotne "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Pakotņu saraksts";
+      return "Pakotne "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1366,14 +1368,18 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Pakas funkcijas";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Pakas elementi";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statiskās pakas funkcijas";
     }
@@ -1485,18 +1491,10 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     virtual QCString trDirectories()
     { return "Direktorijas"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Šī direktoriju hierarhija ir aptuveni, "
-             "bet ne pilnībā, alfabēta secībā:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result="Direktorijas "; result+=dirName; result+=" atsauce"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1624,11 +1622,11 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" moduļa"; break;
@@ -1645,7 +1643,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" moduļu atsauce";
@@ -1697,7 +1695,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentācija š";
+      QCString result="Dokumentācija š";
       switch(compType)
       {
         case ClassDef::Class:      result+="im modulim"; break;
@@ -1747,7 +1745,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" relācija";
     }
@@ -1784,18 +1782,18 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"File in "+name;
+      return "File in "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Includes file in "+name;
+      return "Includes file in "+name;
     }
 
     /** Compiles a date string.
@@ -1824,6 +1822,27 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "pirmd.", "otrd.", "trešd.", "ceturtd.", "piektd.", "sestd.", "svētd." };
+      static const char *days_full[]    = { "pirmdiena", "otrdiena", "trešdiena", "ceturtdiena", "piektdiena", "sestdiena", "svētdiena" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "janv.", "febr.", "marts", "apr.", "maijs", "jūn.", "jūl.", "aug.", "sept.", "okt.", "nov.", "dec." };
+      static const char *months_full[]  = { "janvāris", "februāris", "marts", "aprīlis", "maijs", "jūnijs", "jūlijs", "augusts", "septembris", "oktobris", "novembris", "decembris" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "priekšp.", "pēcp." };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1838,7 +1857,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     { return "Autortiesības"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Atkarību grafs direktorijai ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1868,11 +1887,11 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" uzskaitījumliterāļa atsauce"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" manto no "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1901,7 +1920,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trProvidedByCategory()
     {
-      return "Nodrošina kategorija @1.";
+      return "Nodrošina kategorija @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1910,7 +1929,7 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
      */
     virtual QCString trExtendsClass()
     {
-      return "Paplašina klasi @1.";
+      return "Paplašina klasi @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
@@ -1935,17 +1954,6 @@ class TranslatorLatvian : public TranslatorAdapter_1_8_4
     {
       return "Metožu dokumentācija";
     }
-
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "Dizaina pārskats";
-    }
-
-//////////////////////////////////////////////////////////////////////////
-
 };
 
 #endif
