@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -26,7 +26,7 @@
 #ifndef TRANSLATOR_RU_H
 #define TRANSLATOR_RU_H
 
-class TranslatorRussian : public Translator
+class TranslatorRussian : public TranslatorAdapter_1_8_15
 {
   public:
     /*! Used for identification of the language. */
@@ -35,8 +35,13 @@ class TranslatorRussian : public Translator
 
     /* Used to get the command(s) for the language support. */
     virtual QCString latexLanguageSupportCommand()
+    { return "\\usepackage[T2A]{fontenc}\n\\usepackage[russian]{babel}\n"; }
+
+    virtual QCString trISOLang()
+    { return "ru"; }
+    virtual QCString getLanguageString()
     {
-        return "\\usepackage[T2A]{fontenc}\n\\usepackage[russian]{babel}\n";
+      return "0x419 Russian";
     }
 
     // --- Language translation methods -------------------
@@ -68,7 +73,7 @@ class TranslatorRussian : public Translator
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля";
       }
@@ -83,35 +88,35 @@ class TranslatorRussian : public Translator
     { return "Подробнее..."; }
 
     /*! put in the class documentation */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trListOfAllMembers()
     {
       return "Полный список членов класса";
     }
 
     /*! used as the title of the "list of all members" page of a class */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trMemberList()
     {
       return "Cписок членов класса";
     }
 
     /*! this is the first part of a sentence that is followed by a class name */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trThisIsTheListOfAllMembers()
     { return "Полный список членов класса "; }
 
     /*! this is the remainder of the sentence after the class name */
-    /* Dosn't use when optimization for C is on. */
+    /* Isn't used when optimization for C is on. */
     virtual QCString trIncludingInheritedMembers()
     { return ", включая наследуемые из базового класса"; }
 
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Автоматически создано Doxygen";
-      if (s) result+=QCString(" для ")+s;
+      if (!s.isEmpty()) result+=QCString(" для ")+s;
       result+=" из исходного текста.";
       return result;
     }
@@ -143,7 +148,7 @@ class TranslatorRussian : public Translator
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -160,7 +165,7 @@ class TranslatorRussian : public Translator
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля структур";
       }
@@ -207,10 +212,14 @@ class TranslatorRussian : public Translator
     /*! This is an introduction to the annotated compound list. */
     virtual QCString trCompoundListDescription()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных с их кратким описанием.";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Классы с их кратким описанием.";
+      }
       else
       {
         return "Классы с их кратким описанием.";
@@ -222,20 +231,20 @@ class TranslatorRussian : public Translator
     {
         QCString result="Список всех ";
         if(!extractAll) result+="документированных ";
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
           result+="членов структур данных со ссылками на ";
         else
           result+="членов классов со ссылками на ";
         if(!extractAll)
         {
-          if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             result+="документацию по структуре для каждого члена.";
           else
             result+="документацию по классу для каждого члена.";
         }
         else
         {
-          if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+          if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             result += "структуры";
           else
             result += "классы";
@@ -250,7 +259,7 @@ class TranslatorRussian : public Translator
       QCString result="Список всех ";
       if (!extractAll) result+="документированных ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="функций, переменных, макроопределений, "
                 "перечислений и определений типов";
@@ -303,7 +312,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Алфавитный указатель структур данных";
       }
@@ -330,10 +339,14 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Классы";
@@ -352,12 +365,6 @@ class TranslatorRussian : public Translator
     virtual QCString trExampleDocumentation()
     { return "Примеры"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Тематические описания"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Оглавление"; }
@@ -433,7 +440,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -450,25 +457,21 @@ class TranslatorRussian : public Translator
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
       QCString result="Документация ";
-      if (projName) result+=QCString("по ")+projName;
+      if (!projName.isEmpty()) result+=QCString("по ")+projName;
       result+=QCString(". Последние изменения: ")+date;
       result+=". Создано системой";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
       return QCString("Граф наследования:")+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Только для внутреннего использования"; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Предупреждения"; }
@@ -540,7 +543,7 @@ class TranslatorRussian : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                  ClassDef::CompoundType compType,
                                  bool isTemplate)
     {
@@ -579,13 +582,13 @@ class TranslatorRussian : public Translator
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       return QCString("Файл ")+fileName;
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       return QCString("Пространство имен ")+namespaceName;
     }
@@ -797,14 +800,14 @@ class TranslatorRussian : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Граф связей класса "+clName+":";
+      return "Граф связей класса "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Граф включаемых заголовочных файлов для "+fName+":";
+      return "Граф включаемых заголовочных файлов для "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -877,7 +880,7 @@ class TranslatorRussian : public Translator
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Поля данных";
       }
@@ -1004,7 +1007,7 @@ class TranslatorRussian : public Translator
         "\\endcode\n"
         "Если \\c MAX_DOT_GRAPH_HEIGHT в конфигурационном файле "
         "установлен в 240, получится следующий граф:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "Прямоугольники в этом графе имеют следующее значение:\n"
         "<ul>\n"
@@ -1074,7 +1077,7 @@ class TranslatorRussian : public Translator
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Структуры данных";
       }
@@ -1084,15 +1087,10 @@ class TranslatorRussian : public Translator
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
       return QCString("Пакет ")+name;
     }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Полный список пакетов ";
-    }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
@@ -1149,7 +1147,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trClass(bool first_capital, bool singular)
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         QCString result((first_capital ? "Структуры данных" : "структуры данных"));
         return result;
@@ -1326,14 +1324,18 @@ class TranslatorRussian : public Translator
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Функции с областью видимости пакета";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Члены с областью видимости пакета";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Статические функции с областью видимости пакета";
     }
@@ -1445,16 +1447,10 @@ class TranslatorRussian : public Translator
     virtual QCString trDirectories()
     { return "Алфавитный указатель директорий"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Дерево директорий"; }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=QCString("Содержание директории ")+ dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1584,11 +1580,11 @@ class TranslatorRussian : public Translator
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate)
       {
 	switch(compType)
@@ -1621,7 +1617,7 @@ class TranslatorRussian : public Translator
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       return QCString("Модуль ") + namespaceName;
     }
@@ -1670,7 +1666,7 @@ class TranslatorRussian : public Translator
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Документация по ";
+      QCString result="Документация по ";
       switch(compType)
       {
         case ClassDef::Class:      result+="модулю"; break;
@@ -1717,7 +1713,7 @@ class TranslatorRussian : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return QCString(name)+" Связь";
     }
@@ -1754,18 +1750,18 @@ class TranslatorRussian : public Translator
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Файл в "+name;
+      return "Файл в "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Включает файл в "+name;
+      return "Включает файл в "+name;
     }
 
     /** Compiles a date string.
@@ -1794,6 +1790,25 @@ class TranslatorRussian : public Translator
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "Пн", "Вт", "Ср", "Чт", "Пт", "Сб", "Вс" };
+      static const char *days_full[]    = { "понедельник", "вторник", "среда", "четверг", "пятница", "суббота", "воскресенье" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "янв", "фев", "мар", "апр", "май", "июн", "июл", "авг", "сен", "окт", "ноя", "дек" };
+      static const char *months_full[]  = { "Январь", "Февраль", "Март", "Апрель", "Май", "Июнь", "Июль", "Август", "Сентябрь", "Октябрь", "Ноябрь", "Декабрь" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "AM", "PM" };
+      return dayPeriod[period];
+    }
 
 ///////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1808,7 +1823,7 @@ class TranslatorRussian : public Translator
     { return "Авторство"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Директория графа зависимостей ")+name+":"; }
 
 ///////////////////////////////////////////////////////////////////////
@@ -1836,11 +1851,11 @@ class TranslatorRussian : public Translator
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" Ссылки на перечисление"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" унаследованные от "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1869,7 +1884,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trProvidedByCategory()
     {
-      return "По группам @1.";
+      return "По группам @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1878,7 +1893,7 @@ class TranslatorRussian : public Translator
      */
     virtual QCString trExtendsClass()
     {
-      return "Расширяет класс @1.";
+      return "Расширяет класс @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
@@ -1904,14 +1919,6 @@ class TranslatorRussian : public Translator
       return "Документация метода";
     }
 
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "Обзор дизайна";
-    }
-
 ///////////////////////////////////////////////////////////////////////
 // new since 1.8.4
 ///////////////////////////////////////////////////////////////////////
@@ -1929,23 +1936,23 @@ class TranslatorRussian : public Translator
     { return "Постоянные группы"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" Ссылка на постоянную группу";
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Ссылка на сервис";
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Ссылка на одиночку";
       return result;
     }
@@ -1953,7 +1960,7 @@ class TranslatorRussian : public Translator
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Документация для этого сервиса "
+      QCString result="Документация для этого сервиса "
                                 "сгенерирована из следующего файл";
       if (single) result+="а:"; else result+="ов:";
       return result;
@@ -1962,13 +1969,11 @@ class TranslatorRussian : public Translator
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Документация по этому одиночке "
+      QCString result="Документация по этому одиночке "
                                 "сгенерирована из следующего файл";
       if (single) result+="а:"; else result+="ов:";
       return result;
     }
-
-///////////////////////////////////////////////////////////////////////
 };
 
 #endif
