@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -58,6 +58,14 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       QCString result="\\usepackage[serbian]{babel}\n";
       return result;
     }
+    virtual QCString trISOLang()
+    {
+      return "sr-Latn";
+    }
+    virtual QCString getLanguageString()
+    {
+      return "0x81A Serbian (Serbia, Latin)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -91,7 +99,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dokumentacija polja";
       }
@@ -124,9 +132,9 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Napravljeno automatski korišćenjem alata Doxygen";
-      if( s ) result+=(QCString)" za projekat " + s;
+      if (!s.isEmpty()) result+=" za projekat " + s;
       result+=" od izvornog koda.";
       return result;
     }
@@ -158,7 +166,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Spisak struktura";
       }
@@ -175,7 +183,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Sva polja struktura";
       }
@@ -188,7 +196,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      //if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      //if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       //{
       // return "Članovi datoteke"; // TODO: translate me
       //}
@@ -227,10 +235,14 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     virtual QCString trCompoundListDescription()
     {
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Spisak struktura sa kratkim opisima:";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Spisak klasa sa kratkim opisima:";
+      }
       else
       {
         return "Spisak klasa, struktura, unija i interfejsa sa kratkim opisima:";
@@ -245,7 +257,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       {
         result+="dokumentovanih ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="članova struktura/unija";
       }
@@ -256,7 +268,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       result+=" sa vezama ka ";
       if (extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="dokumentaciji svakog polja strukture/unije:";
         }
@@ -267,7 +279,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="strukturama/unijama kojima pripadaju:";
         }
@@ -285,7 +297,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       QCString result="Spisak svih ";
       if (!extractAll) result+="dokumentovanih ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="funkcija, promenljivih, makro zamena, nabrajanja i definicija tipa";
       }
@@ -336,7 +348,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Spisak struktura/unija";
       }
@@ -363,10 +375,14 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dokumentacija stuktura/unija";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Dokumentacija klasa";
@@ -385,12 +401,6 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     virtual QCString trExampleDocumentation()
     { return "Dokumentacija primera"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Dokumentacija stranice"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Priručnik"; }
@@ -466,7 +476,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Strukture i unije";
       }
@@ -479,24 +489,20 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"[" + date + "] Napravljeno automatski ";
-      if ( projName ) result+=(QCString)" za projekat " + projName;
-	  result+=(QCString)" upotrebom ";
+      QCString result="[" + date + "] Napravljeno automatski ";
+      if (!projName.isEmpty()) result+=" za projekat " + projName;
+	  result+=" upotrebom ";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
       return QCString("Dijagram nasleđivanja za klasu ") + clName + ":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Samo za unutrašnju upotrebu."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Upozorenje"; }
@@ -567,7 +573,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -589,7 +595,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result = "Opis datoteke ";
       result += fileName;
@@ -597,7 +603,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result="Opis prostora imena ";
       result += namespaceName;
@@ -731,7 +737,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacija ";
+      QCString result="Dokumentacija ";
       switch(compType)
       {
         case ClassDef::Class:      result+="ove klase"; break;
@@ -794,14 +800,14 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Klasni dijagram za "+clName+":";
+      return "Klasni dijagram za "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Graf zavisnosti datoteka za "+fName+":";
+      return "Graf zavisnosti datoteka za "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -874,7 +880,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Polja";
       }
@@ -1001,7 +1007,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
         "\\endcode\n"
         "Ako je \\c MAX_DOT_GRAPH_HEIGHT tag u konfiguracionoj datoteci "
         "postavljen na \\c 200 graf izvođenja će izgledati ovako:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "Graf će biti odsečen ako ne stane unutar zadatih granica.\n"
         "<p>\n"
         "Pravougaonici imaju sledeća značenja:\n"
@@ -1069,7 +1075,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Strukture i unije";
       }
@@ -1079,14 +1085,9 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paket "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Spisak paketa";
+      return "Paket "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1344,14 +1345,18 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funkcije u paketu";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Članovi u paketu";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statičke funkcije u paketu";  // Zajednicke funkcije u paketu
     }
@@ -1463,16 +1468,10 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     virtual QCString trDirectories()
     { return "Direktorijumi"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Hijerarhija direktorijuma uređena približno po abecedi:"; }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+="Opis direktorijuma"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1600,11 +1599,11 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Modul"; break;
@@ -1621,7 +1620,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+=" - sažet pregled modula";
@@ -1672,7 +1671,7 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentacija za ovaj ";
+      QCString result="Dokumentacija za ovaj ";
       switch(compType)
       {
         case ClassDef::Class:      result+="modul"; break;
@@ -1715,60 +1714,33 @@ class TranslatorSerbian : public TranslatorAdapter_1_6_0
       return "Ograničenja tipova";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// following methods have no corresponding entry in translator_en.h
-//////////////////////////////////////////////////////////////////////////
-
-//      /*! This is put above each page as a link to the list of all verbatim headers */
-//     virtual QCString trHeaderFiles()
-//     { return "Zaglavlja"; }
-//
-//     /*! This is an introduction to the page with the list of all header files. */
-//     virtual QCString trHeaderFilesDescription()
-//     { return "Zaglavlja koje izgraduju API:"; }
-//
-//     /*! This sentences is used in the annotated class/file lists if no brief
-//      * description is given.
-//      */
-//     virtual QCString trNoDescriptionAvailable()
-//     { return "Opis nije dostupan"; }
-//
-//     /*! this text is generated when the \\reimp command is used. */
-//     virtual QCString trReimplementedForInternalReasons()
-//     { return decode("Preuradeno zbog unutrasnjih razloga; Nema uticaja na API." ); }
-//
-//     /*! this text is generated when the \\bug command is used. */
-//     virtual QCString trBugsAndLimitations()
-//     { return "Greske i ogranicenja"; }
-//
-//     virtual QCString trSources()
-//     {
-//       return decode("Izvorne datoteke" );
-//     }
-//
-//     /*! Used for Java interfaces in the summary section of Java packages */
-//     virtual QCString trInterfaces()
-//     {
-//       return "Interfejsi";  //!< Radna okruzenja. Ali to je dve reci.
-//     }
-//
-//     /*! Used as a chapter title for Latex & RTF output */
-//     virtual QCString trPackageDocumentation()
-//     {
-//       return "Dokumentacija paketa";
-//     }
-//
-//     /*! This is used for translation of the word that will possibly
-//      *  be followed by a single name or by a list of names
-//      *  of the category.
-//      */
-//     virtual QCString trField(bool first_capital, bool singular)
-//     {
-//       QCString result((first_capital ? "Polj" : "polj"));
-//       result+= (singular ? "e" : "a");
-//       return result;
-//     }
+    /*! Used for Java interfaces in the summary section of Java packages */
+    virtual QCString trInterfaces()
+    {
+      return "Interfejsi";  //!< Radna okruzenja. Ali to je dve reci.
+    }
 
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "pon", "uto", "sre", "čet", "pet", "sub", "ned" };
+      static const char *days_full[]    = { "ponedeljak", "utorak", "sreda", "četvrtak", "petak", "subota", "nedelja" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "jan", "feb", "mar", "apr", "maj", "jun", "jul", "avg", "sep", "okt", "nov", "dec" };
+      static const char *months_full[]  = { "januar", "februar", "mart", "april", "maj", "jun", "jul", "avgust", "septembar", "oktobar", "novembar", "decembar" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "pre podne", "po podne" };
+      return dayPeriod[period];
+    }
 };
 
 #endif
