@@ -95,6 +95,11 @@ I left use clause untouched as I didn't find a suitable translation for it.
 English:
 * Updated the language translation to 1.8.19
 
+2020/08/19
+* Uppdaterat översättningarna till 1.9.2
+English:
+* Updated the language translation to 1.9.2
+
 ===================================================================================
   Ordlista
 ===================================================================================
@@ -151,7 +156,7 @@ English:
 #ifndef TRANSLATOR_SE_H
 #define TRANSLATOR_SE_H
 
-class TranslatorSwedish : public TranslatorAdapter_1_9_2
+class TranslatorSwedish : public TranslatorAdapter_1_9_4
 {
   public:
 
@@ -181,6 +186,10 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     {
       return "sv";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x41D Swedish";
+    }
 
     // --- Language translation methods -------------------
 
@@ -246,7 +255,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
      */
     virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automatiskt skapad av Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" för "+s;
+      if (!s.isEmpty()) result+=" för "+s;
       result+=" från källkoden.";
       return result;
     }
@@ -495,6 +504,10 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
       {
         return "Dokumentation över datastrukturer";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klassdokumentation";
@@ -513,12 +526,6 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     virtual QCString trExampleDocumentation()
     { return "Exempeldokumentation"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Sid-dokumentation"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Referensmanual"; }
@@ -609,22 +616,18 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
      */
     virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Skapad "+date;
-      if (!projName.isEmpty()) result+=(QCString)" för "+projName;
-      result+=(QCString)" av";
+      QCString result="Skapad "+date;
+      if (!projName.isEmpty()) result+=" för "+projName;
+      result+=" av";
       return result;
     }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Klassdiagram för "+clName;
+      return "Klassdiagram för "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Endast för internt bruk."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Varning"; }
@@ -696,7 +699,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:  result+=" klass"; break;
@@ -866,10 +869,11 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentationen för ";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="Dokumentationen för ";
       switch(compType)
       {
-        case ClassDef::Class:      result+="denna klass"; break;
+        case ClassDef::Class:      result+=vhdlOpt? "denna designenhets":"denna klass"; break;
         case ClassDef::Struct:     result+="denna strukt"; break;
         case ClassDef::Union:      result+="denna union"; break;
         case ClassDef::Interface:  result+="detta gränssnitt"; break;
@@ -931,12 +935,12 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Samarbetsdiagram för "+clName+":";
+      return "Samarbetsdiagram för "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Include-beroendediagram för "+fName+":";
+      return "Include-beroendediagram för "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1219,12 +1223,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paket "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Paketlista";
+      return "Paket "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1469,14 +1468,18 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Paketfunktioner";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Paketmedlemmar";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statiska paketfunktioner";
     }
@@ -1588,14 +1591,6 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     virtual QCString trDirectories()
     { return "Kataloger"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Den här katalogen är grovt sorterad, "
-             "men inte helt, i alfabetisk ordning:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1732,7 +1727,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Modul"; break;
@@ -1801,7 +1796,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentationen för ";
+      QCString result="Dokumentationen för ";
       switch(compType)
       {
         case ClassDef::Class:      result+="denna modul"; break;
@@ -1889,7 +1884,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Fil i "+name;
+      return "Fil i "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1898,7 +1893,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Inkluderar fil i "+name;
+      return "Inkluderar fil i "+name;
     }
 
     /** Compiles a date string.
@@ -1927,6 +1922,27 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "mån", "tis", "ons", "tor", "fre", "lör", "sön" };
+      static const char *days_full[]    = { "måndag", "tisdag", "onsdag", "torsdag", "fredag", "lördag", "söndag" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "jan", "feb", "mar", "apr", "maj", "jun", "jul", "aug", "sep", "okt", "nov", "dec" };
+      static const char *months_full[]  = { "januari", "februari", "mars", "april", "maj", "juni", "juli", "augusti", "september", "oktober", "november", "december" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "fm", "em" };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -2063,14 +2079,14 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     /** UNO IDL service page title */
     virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Tjänstereferens";
       return result;
     }
     /** UNO IDL singleton page title */
     virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Singleton-referens";
       return result;
     }
@@ -2078,7 +2094,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentationen för denna tjänst "
+      QCString result="Dokumentationen för denna tjänst "
                                 "genererades från följande fil";
       if (single) result+=":"; else result+="er:";
       return result;
@@ -2087,7 +2103,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Dokumentationen för denna singleton "
+      QCString result="Dokumentationen för denna singleton "
                                 "genererades från följande fil";
       if (single) result+=":"; else result+="er:";
       return result;
@@ -2313,7 +2329,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     }
     virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isLocal) result+=" Lokal";
       switch(compType)
       {
@@ -2354,5 +2370,49 @@ class TranslatorSwedish : public TranslatorAdapter_1_9_2
     virtual QCString trDesignUnitDocumentation()
     { return "Designenhetsdokumentation"; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.2
+//////////////////////////////////////////////////////////////////////////
+
+    /** C++20 concept */
+    virtual QCString trConcept(bool first_capital, bool singular)
+    {
+      QCString result((first_capital ? "Koncept" : "koncept"));
+      return result;
+    }
+    /*! used as the title of the HTML page of a C++20 concept page */
+    virtual QCString trConceptReference(const QCString &conceptName)
+    {
+      QCString result=conceptName;
+      result+=" Konceptreferens";
+      return result;
+    }
+
+    /*! used as the title of page containing all the index of all concepts. */
+    virtual QCString trConceptList()
+    { return "Konceptlista"; }
+
+    /*! used as the title of chapter containing the index listing all concepts. */
+    virtual QCString trConceptIndex()
+    { return "Konceptindex"; }
+
+    /*! used as the title of chapter containing all information about concepts. */
+    virtual QCString trConceptDocumentation()
+    { return "Konceptdokumentation"; }
+
+    /*! used as an introduction to the concept list */
+    virtual QCString trConceptListDescription(bool extractAll)
+    {
+      QCString result="Här är listan över alla ";
+      if (!extractAll) result+="dokumenterade ";
+      result+="koncept med en kort beskrivning:";
+      return result;
+    }
+
+    /*! used to introduce the definition of the C++20 concept */
+    virtual QCString trConceptDefinition()
+    {
+      return "Konceptdefinition";
+    }
 };
 #endif
